@@ -21,8 +21,10 @@ from .create_resunet_model import create_resunet_model_2d, create_resunet_model_
 from .create_denseunet_model import create_denseunet_model_2d, create_denseunet_model_3d
 from .create_custom_unet_model import create_nobrainer_unet_model_3d
 from .create_custom_unet_model import create_hippmapp3r_unet_model_3d
+from .create_custom_unet_model import create_hypermapp3r_unet_model_3d
 from .create_custom_unet_model import create_sysu_media_unet_model_2d
 from .create_custom_unet_model import create_hypothalamus_unet_model_3d
+from .create_partial_convolution_unet_model import create_partial_convolution_unet_model_2d, create_partial_convolution_unet_model_3d
 
 from .create_custom_model import create_simple_fully_convolutional_network_model_3d
 
