@@ -44,6 +44,8 @@ from .custom_normalization_layers import InstanceNormalization
 
 from .custom_activation_layers import LogSoftmax
 
+from .custom_convolution_layers import PartialConv2D, PartialConv3D
+
 from .cropping_and_padding_utilities import crop_image_center
 from .cropping_and_padding_utilities import pad_or_crop_image_to_size
 from .cropping_and_padding_utilities import pad_image_by_factor
@@ -56,14 +58,17 @@ from .data_augmentation import data_augmentation
 
 from .preprocess_image import preprocess_brain_image
 from .brain_extraction import brain_extraction
+from .inpainting import whole_head_inpainting
 from .cortical_thickness import cortical_thickness
 from .cortical_thickness import longitudinal_cortical_thickness
 from .histology import arterial_lesion_segmentation
 from .histology import allen_ex5_brain_extraction
 from .histology import allen_histology_brain_mask
+from .histology import allen_histology_hemispherical_coronal_mask
 from .lung_extraction import lung_extraction
 from .white_matter_hyperintensity_segmentation import sysu_media_wmh_segmentation
 from .white_matter_hyperintensity_segmentation import ew_david
+from .white_matter_hyperintensity_segmentation import hypermapp3r_segmentation
 from .claustrum_segmentation import claustrum_segmentation
 from .hypothalamus_segmentation import hypothalamus_segmentation
 from .hippmapp3r_segmentation import hippmapp3r_segmentation
