@@ -90,6 +90,7 @@ def get_pretrained_network(file_id=None,
             "ex5_coronal_weights": "https://figshare.com/ndownloader/files/38035968",
             "ex5_sagittal_weights": "https://figshare.com/ndownloader/files/38035965",
             "allen_brain_mask_weights" : "https://figshare.com/ndownloader/files/36999880",
+            "allen_brain_leftright_coronal_mask_weights" : "",
             "ewDavidSysu": "https://ndownloader.figshare.com/files/28757622", # "https://ndownloader.figshare.com/files/28403973",
             "ewDavidSysuRankedIntensity": "https://ndownloader.figshare.com/files/28403937",
             "ewDavidSysuT1Only": "https://ndownloader.figshare.com/files/28757628", #"https://ndownloader.figshare.com/files/28403934",
@@ -113,6 +114,7 @@ def get_pretrained_network(file_id=None,
             "functionalLungMri": "https://ndownloader.figshare.com/files/13824167",
             "hippMapp3rInitial": "https://ndownloader.figshare.com/files/18068408",
             "hippMapp3rRefine": "https://ndownloader.figshare.com/files/18068411",
+            "hyperMapp3r": "https://figshare.com/ndownloader/files/38790702",
             "hypothalamus": "https://ndownloader.figshare.com/files/28344378",
             "koniqMBCS": "https://ndownloader.figshare.com/files/24967376",
             "koniqMS": "https://figshare.com/ndownloader/files/35295403",
@@ -132,6 +134,10 @@ def get_pretrained_network(file_id=None,
             "sysuMediaWmhFlairT1Model1": "https://ndownloader.figshare.com/files/22898453",
             "sysuMediaWmhFlairT1Model2": "https://ndownloader.figshare.com/files/22898459",
             "tidsQualityAssessment": "https://figshare.com/ndownloader/files/35295391",
+            "wholeHeadInpaintingT1": "https://figshare.com/ndownloader/files/39255422",
+            "wholeHeadInpaintingPatchBasedT1": "https://figshare.com/ndownloader/files/39337442",
+            "wholeHeadInpaintingPatchBasedFLAIR": "https://figshare.com/ndownloader/files/39337439",
+            "wholeHeadInpaintingFLAIR": "https://figshare.com/ndownloader/files/39255419",
             "wholeTumorSegmentationT2Flair": "https://ndownloader.figshare.com/files/14087045",
             "wholeLungMaskFromVentilation": "https://ndownloader.figshare.com/files/28914441"
         }
@@ -195,6 +201,7 @@ def get_pretrained_network(file_id=None,
                   "ex5_coronal_weights",
                   "ex5_sagittal_weights",
                   "allen_brain_mask_weights",
+                  "allen_brain_leftright_coronal_mask_weights",
                   "elBicho",
                   "ewDavidSysu",
                   "ewDavidSysuRankedIntensity",
@@ -219,6 +226,7 @@ def get_pretrained_network(file_id=None,
                   "functionalLungMri",
                   "hippMapp3rInitial",
                   "hippMapp3rRefine",
+                  "hyperMapp3r",
                   "hypothalamus",
                   "koniqMBCS",
                   "koniqMS",
@@ -239,6 +247,10 @@ def get_pretrained_network(file_id=None,
                   "sysuMediaWmhFlairT1Model1",
                   "sysuMediaWmhFlairT1Model2",
                   "tidsQualityAssessment",
+                  "wholeHeadInpaintingT1",
+                  "wholeHeadInpaintingFLAIR",
+                  "wholeHeadInpaintingPatchBasedT1",
+                  "wholeHeadInpaintingPatchBasedFLAIR",
                   "wholeTumorSegmentationT2Flair",
                   "wholeLungMaskFromVentilation",
                   "show")
