@@ -235,7 +235,7 @@ def allen_histology_brain_mask(image,
                                verbose=False):
 
     """
-    Determine brain foreground of Allen's mouse embroyonic data.
+    Determine brain foreground of Allen's mouse data.
 
     Arguments
     ---------
@@ -363,3 +363,156 @@ def allen_histology_brain_mask(image,
 
     return(foreground_probability_image)
 
+def allen_histology_hemispherical_coronal_mask(image,
+                                               which_axis=2,
+                                               antsxnet_cache_directory=None,
+                                               verbose=False):
+
+    """
+    Determine left and right hemisphere brain masks of Allen's mouse data in coronal 
+    acquisitions for both P* and E*x5 data.  This assumes that the original histology
+    image has been pre-extracted.
+
+    Arguments
+    ---------
+    image : ANTsImage
+        input image
+
+    which_axis : integer
+        If 3-D image, which_axis specifies the direction of the coronal view.
+
+    antsxnet_cache_directory : string
+        Destination directory for storing the downloaded template and model weights.
+        Since these can be resused, if is None, these data will be downloaded to a
+        ~/.keras/ANTsXNet/.
+
+    verbose : boolean
+        Print progress to the screen.
+
+    Returns
+    -------
+    Foreground probability image.
+
+    Example
+    -------
+    >>> output = allen_histology_hemispherical_coronal_mask(histology_image)
+    """
+
+    from ..architectures import create_unet_model_2d
+    from ..utilities import get_pretrained_network
+
+    if antsxnet_cache_directory == None:
+        antsxnet_cache_directory = "ANTsXNet"
+
+    if which_axis < 0 or which_axis > 2:
+        raise ValueError("Chosen axis not supported.")
+
+    weights_file_name = get_pretrained_network("allen_brain_leftright_coronal_mask_weights",
+        antsxnet_cache_directory=antsxnet_cache_directory)
+
+    resampled_image_size = (512, 512)
+    original_slice_shape = image.shape
+    if image.dimension > 2:
+        original_slice_shape = tuple(np.delete(np.array(image.shape), which_axis))
+
+    classes = (0, 1, 2)
+    number_of_classification_labels = len(classes)
+
+    unet_model = create_unet_model_2d((*resampled_image_size, 1),
+        number_of_outputs=number_of_classification_labels, mode="classification",
+        number_of_filters=(64, 96, 128, 256, 512),
+        convolution_kernel_size=(3, 3), deconvolution_kernel_size=(2, 2),
+        dropout_rate=0.0, weight_decay=0,
+        additional_options=("initialConvolutionKernelSize[5]", "attentionGating"))
+    unet_model.load_weights(weights_file_name)
+
+    if verbose:
+        print("Preprocessing:  Resampling.")
+
+    number_of_channels = image.components
+    number_of_slices = 1
+    if image.dimension > 2:
+        number_of_slices = image.shape[which_axis]
+    
+    image_channels = list()
+    if number_of_channels == 1:
+        image_channels.append(image)
+    else:
+        image_channels = ants.split_channels(image)
+     
+    batch_X = np.zeros((number_of_channels * number_of_slices, *resampled_image_size, 1))
+    
+    count = 0
+    for i in range(number_of_channels):
+        image_channel_array = image_channels[i].numpy()
+        for j in range(number_of_slices):
+            slice = None
+            if image.dimension > 2:
+                if which_axis == 0:
+                    image_channel_slice_array = np.squeeze(image_channel_array[j,:,:])
+                elif which_axis == 1:
+                    image_channel_slice_array = np.squeeze(image_channel_array[:,j,:])
+                else:
+                    image_channel_slice_array = np.squeeze(image_channel_array[:,:,j])
+                slice = ants.from_numpy(image_channel_slice_array)
+            else:
+                slice = image_channels[i]
+            if slice.max() > slice.min():
+                slice_resampled = ants.resample_image(slice, resampled_image_size, use_voxels=True, interp_type=0)
+                slice_smoothed = ants.smooth_image(slice_resampled, 1.0)
+                slice_array = slice_smoothed.numpy()
+                slice_array = (slice_array - slice_array.min()) / (slice_array.max() - slice_array.min())
+                batch_X[count,:,:,0] = slice_array
+            count = count + 1
+
+    if verbose:
+        print("Prediction: ")
+
+    predicted_data = unet_model.predict(batch_X, verbose=int(verbose))
+    if number_of_channels > 1:
+        if verbose:
+            print("Averaging across channels.")
+        predicted_data_temp = np.split(predicted_data, number_of_channels, axis=0) 
+        predicted_data = np.zeros((number_of_slices, *resampled_image_size, 1))
+        for i in range(number_of_channels):
+            predicted_data = (predicted_data * i + predicted_data_temp[i]) / (i + 1)
+
+    if verbose:
+        print("Post-processing:  resampling to original space.")
+
+    origin = image.origin
+    spacing = image.spacing
+    direction = image.direction
+
+    probability_images = list()
+    for i in range(len(classes)):
+        if verbose == True:
+            print("Reconstructing image", classes[i])
+
+        probability_image_array = np.zeros(image.shape)
+        for j in range(number_of_slices):
+            slice_resampled = ants.from_numpy(np.squeeze(predicted_data[j,:,:,i]))
+            slice = ants.resample_image(slice_resampled, original_slice_shape, use_voxels=True, interp_type=0)
+            if image.dimension == 2: 
+                probability_image_array[:,:] = slice.numpy()
+            else:
+                if which_axis == 0:
+                    probability_image_array[j,:,:] = slice.numpy()
+                elif which_axis == 1:
+                    probability_image_array[:,j,:] = slice.numpy()
+                else:
+                    probability_image_array[:,:,j] = slice.numpy()
+
+        probability_images.append(ants.from_numpy(probability_image_array,
+            origin=origin, spacing=spacing, direction=direction))
+
+    image_matrix = ants.image_list_to_matrix(probability_images, image_channels[0] * 0 + 1)
+    segmentation_matrix = np.argmax(image_matrix, axis=0)
+    segmentation_image = ants.matrix_to_images(
+        np.expand_dims(segmentation_matrix, axis=0), image_channels[0] * 0 + 1)[0]
+
+    return_dict = {'segmentation_image' : segmentation_image,
+                   'probability_images' : probability_images}
+    return(return_dict)
+
+
